@@ -1,14 +1,19 @@
 """Callbacks for the Endpoints Subpage Web User Interface"""
 
-from dash import Dash, no_update
+import logging
+from dash import Dash, callback, no_update
+from dash.exceptions import PreventUpdate
 from dash.dependencies import Input, Output, State
 
 # SageWorks Imports
-from sageworks.views.endpoint_web_view import EndpointWebView
+from sageworks.web_views.endpoint_web_view import EndpointWebView
 from sageworks.web_components import table, endpoint_metric_plots
 from sageworks.utils.pandas_utils import deserialize_aws_broker_data
 from sageworks.api.endpoint import Endpoint
 
+# Get the SageWorks logger
+log = logging.getLogger("sageworks")
+
 
 def update_endpoints_table(app: Dash):
     @app.callback(
@@ -74,31 +79,42 @@ def update_endpoint_metrics(app: Dash, endpoint_web_view: EndpointWebView):
         endpoint_details = endpoint_web_view.endpoint_details(endpoint_uuid)
 
         # Endpoint Metrics
-        endpoint_metrics_figure = endpoint_metric_plots.EndpointMetricPlots().update_contents(endpoint_details)
+        endpoint_metrics_figure = endpoint_metric_plots.EndpointMetricPlots().update_properties(endpoint_details)
 
         # Return the details/markdown for these data details
         return endpoint_metrics_figure
 
 
-# Updates the plugin component when a endpoint row is selected
-def update_plugin(app: Dash, plugin, endpoint_web_view: EndpointWebView):
-    @app.callback(
-        Output(plugin.component_id(), "figure"),
+# Set up the plugin callbacks that take an endpoint
+def setup_plugin_callbacks(plugins):
+
+    # First we'll register internal callbacks for the plugins
+    for plugin in plugins:
+        plugin.register_internal_callbacks()
+
+    # Now we'll set up the plugin callbacks for their main inputs (endpoints in this case)
+    @callback(
+        # Aggregate plugin outputs
+        [Output(component_id, prop) for p in plugins for component_id, prop in p.properties],
         Input("endpoints_table", "derived_viewport_selected_row_ids"),
         State("endpoints_table", "data"),
-        prevent_initial_call=True,
     )
-    def update_callback(selected_rows, table_data):
+    def update_all_plugin_properties(selected_rows, table_data):
         # Check for no selected rows
         if not selected_rows or selected_rows[0] is None:
-            return no_update
+            raise PreventUpdate
 
         # Get the selected row data and grab the uuid
         selected_row_data = table_data[selected_rows[0]]
-        endpoint_uuid = selected_row_data["uuid"]
+        object_uuid = selected_row_data["uuid"]
 
-        # Instantiate the Endpoint and send it to the plugin
-        endpoint = Endpoint(endpoint_uuid, legacy=True)
+        # Create the Endpoint object
+        endpoint = Endpoint(object_uuid, legacy=True)
 
-        # Instantiate the Endpoint and send it to the plugin
-        return plugin.update_contents(endpoint)
+        # Update all the properties for each plugin
+        all_props = []
+        for p in plugins:
+            all_props.extend(p.update_properties(endpoint))
+
+        # Return all the updated properties
+        return all_props
