@@ -9,9 +9,10 @@ from .layout import endpoints_layout
 from . import callbacks
 
 # SageWorks Imports
-from sageworks.web_components import table, endpoint_details, endpoint_metric_plots
+from sageworks.web_components import table, endpoint_metric_plots
+from sageworks.web_components.plugins import endpoint_details
 from sageworks.web_components.plugin_interface import PluginPage
-from sageworks.views.endpoint_web_view import EndpointWebView
+from sageworks.web_views.endpoint_web_view import EndpointWebView
 from sageworks.utils.plugin_manager import PluginManager
 
 # Register this page with Dash
@@ -50,9 +51,12 @@ components = {
 pm = PluginManager()
 plugins = pm.get_list_of_web_plugins(plugin_page=PluginPage.ENDPOINT)
 
+# Our endpoint details is a plugin, so we need to add it to the list
+plugins.append(endpoint_details)
+
 # Add the plugins to the components dictionary
 for plugin in plugins:
-    component_id = plugin.component_id()
+    component_id = plugin.generate_component_id()
     components[component_id] = plugin.create_component(component_id)
 
 # Set up our layout (Dash looks for a var called layout)
@@ -61,12 +65,11 @@ layout = endpoints_layout(**components)
 # Setup our callbacks/connections
 app = dash.get_app()
 callbacks.update_endpoints_table(app)
-endpoint_details.register_callbacks("endpoints_table")
 
 # Callback for the endpoints table
 callbacks.table_row_select(app, "endpoints_table")
 callbacks.update_endpoint_metrics(app, endpoint_broker)
 
-# For each plugin, set up a callback to update the plugin figure
-for plugin in plugins:
-    callbacks.update_plugin(app, plugin, endpoint_broker)
+# For all the plugins we have we'll call their update_properties method
+if plugins:
+    callbacks.setup_plugin_callbacks(plugins)
