@@ -1,17 +1,16 @@
 """SQL based Sample Rows: Compute Sample rows for a DataSource using SQL"""
+
 import logging
 import pandas as pd
 
 # SageWorks Imports
 from sageworks.core.artifacts.data_source_abstract import DataSourceAbstract
 from sageworks.utils.pandas_utils import shorten_values
-from sageworks.utils.trace_calls import trace_calls
 
 # SageWorks Logger
 log = logging.getLogger("sageworks")
 
 
-@trace_calls
 def sample_rows(data_source: DataSourceAbstract) -> pd.DataFrame:
     """Pull a sample of rows from the DataSource
     Args:
@@ -38,7 +37,15 @@ def sample_rows(data_source: DataSourceAbstract) -> pd.DataFrame:
         query = f"SELECT {sql_columns} FROM {table} TABLESAMPLE BERNOULLI({percentage})"
     else:
         query = f"SELECT {sql_columns} FROM {table}"
-    sample_df = data_source.query(query).head(sample_rows)
+    sample_df = data_source.query(query)
+
+    # Sanity Check
+    if sample_df is None:
+        log.error(f"Error pulling sample rows from {data_source.uuid}")
+        return None
+
+    # Grab the first 100 rows
+    sample_df = sample_df.head(sample_rows)
 
     # Shorten any long string values
     sample_df = shorten_values(sample_df)
