@@ -29,7 +29,7 @@ class DataSource(AthenaSource):
         ```
     """
 
-    def __init__(self, source, name: str = None, tags: list = None):
+    def __init__(self, source, name: str = None, tags: list = None, **kwargs):
         """
         Initializes a new DataSource object.
 
@@ -60,7 +60,7 @@ class DataSource(AthenaSource):
         self._load_source(source, name, tags)
 
         # Call superclass init
-        super().__init__(name)
+        super().__init__(name, **kwargs)
 
     def details(self, **kwargs) -> dict:
         """DataSource Details
@@ -81,21 +81,30 @@ class DataSource(AthenaSource):
         """
         return super().query(query)
 
-    def pull_dataframe(self) -> pd.DataFrame:
+    def pull_dataframe(self, include_aws_columns=False) -> pd.DataFrame:
         """Return a DataFrame of ALL the data from this DataSource
 
+        Args:
+            include_aws_columns (bool): Include the AWS columns in the DataFrame (default: False)
+
         Returns:
             pd.DataFrame: A DataFrame of ALL the data from this DataSource
 
         Note:
-            Obviously, this is not recommended for large datasets :)
+            Obviously this is not recommended for large datasets :)
         """
 
         # Get the table associated with the data
         self.log.info(f"Pulling all data from {self.uuid}...")
         table = super().get_table_name()
         query = f"SELECT * FROM {table}"
-        return self.query(query)
+        df = self.query(query)
+
+        # Drop any columns generated from AWS
+        if not include_aws_columns:
+            aws_cols = ["write_time", "api_invocation_time", "is_deleted", "event_time"]
+            df = df.drop(columns=aws_cols, errors="ignore")
+        return df
 
     def to_features(
         self,
@@ -144,7 +153,7 @@ class DataSource(AthenaSource):
         )
 
         # Return the FeatureSet (which will now be up-to-date)
-        return FeatureSet(name)
+        return FeatureSet(name, force_refresh=True)
 
     def _load_source(self, source: str, name: str, tags: list):
         """Load the source of the data"""
