@@ -56,7 +56,7 @@ if __name__ == "__main__":
     print(f"Modified: {my_data.modified()}")
 
     # Column Names and Types
-    print(f"Column Names: {my_data.column_names()}")
+    print(f"Column Names: {my_data.columns}")
     print(f"Column Types: {my_data.column_types()}")
 
     # Get Tags associated with this Artifact
