@@ -355,7 +355,7 @@ class EndpointCore(Artifact):
         from sageworks.utils.endpoint_utils import fs_evaluation_data
 
         eval_data_df = fs_evaluation_data(self)
-        capture_uuid = "training_holdout" if capture else None
+        capture_uuid = "auto_inference" if capture else None
         return self.inference(eval_data_df, capture_uuid)
 
     def inference(self, eval_df: pd.DataFrame, capture_uuid: str = None, id_column: str = None) -> pd.DataFrame:
@@ -738,10 +738,12 @@ class EndpointCore(Artifact):
         prediction_col = "prediction" if "prediction" in prediction_df.columns else "predictions"
         y_pred = prediction_df[prediction_col]
 
-        # Special case for low, medium, high classes
-        if (set(y_true) | set(y_pred)) == {"low", "medium", "high"}:
-            labels = ["low", "medium", "high"]
+        # Check if the target column is an ordinal categorical type
+        if isinstance(y_true.dtype, pd.CategoricalDtype) and y_true.cat.ordered:
+            labels = y_true.cat.categories.tolist()
         else:
+            # Fallback: sort unique values
+            self.log.warning(f"Target column {target_column} is not ordinal, fallback to sorting...")
             labels = sorted(list(set(y_true) | set(y_pred)))
 
         # Compute the confusion matrix
@@ -779,6 +781,10 @@ class EndpointCore(Artifact):
         """Delete an existing Endpoint: Underlying Models, Configuration, and Endpoint"""
         self.delete_endpoint_models()
 
+        # Remove this endpoint from the set of registered endpoints in our model
+        model = ModelCore(self.model_name)
+        model.remove_endpoint(self.uuid)
+
         # Grab the Endpoint Config Name from the AWS
         endpoint_config_name = self.endpoint_config_name()
         try:
@@ -799,10 +805,10 @@ class EndpointCore(Artifact):
 
             # Make sure we add the trailing slash
             s3_path = s3_path if s3_path.endswith("/") else f"{s3_path}/"
-            objects = wr.s3.list_objects(s3_path, boto3_session=self.boto_session)
+            objects = wr.s3.list_objects(s3_path, boto3_session=self.boto3_session)
             for obj in objects:
                 self.log.info(f"Deleting S3 Object {obj}...")
-            wr.s3.delete_objects(objects, boto3_session=self.boto_session)
+            wr.s3.delete_objects(objects, boto3_session=self.boto3_session)
 
         # Now delete any data in the Cache
         for key in self.data_storage.list_subkeys(f"endpoint:{self.uuid}:"):
@@ -891,5 +897,18 @@ if __name__ == "__main__":
     pred_results = my_endpoint.inference(eval_df, capture_uuid="holdout_xyz")
 
     # Run Inference and metrics for a Classification Endpoint
-    class_endpoint = EndpointCore("wine-classification-end")
-    class_endpoint.auto_inference()
+    class_endpoint = EndpointCore("aqsol-mol-class-end")
+    auto_predictions = class_endpoint.auto_inference()
+
+    # Get the confusion matrix
+    target = "solubility_class"
+    print(class_endpoint.confusion_matrix(target, auto_predictions))
+
+    # Now convert the "solubility_class" column to an ordinal categorical type
+    # Convert the "solubility_class" column to an ordinal categorical type in one line
+    auto_predictions["solubility_class"] = auto_predictions["solubility_class"].astype(
+        pd.CategoricalDtype(categories=["low", "medium", "high"], ordered=True)
+    )
+
+    # Get the confusion matrix
+    print(class_endpoint.confusion_matrix(target, auto_predictions))
