@@ -18,6 +18,11 @@ from sageworks.core.artifacts.data_source_factory import DataSourceFactory
 from sageworks.core.artifacts.athena_source import AthenaSource
 from sageworks.aws_service_broker.aws_service_broker import ServiceCategory
 
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from sageworks.core.views import View
+
 
 class FeatureSetCore(Artifact):
     """FeatureSetCore: SageWorks FeatureSetCore Class
@@ -71,7 +76,6 @@ class FeatureSetCore(Artifact):
         # Initialize our Views
         self._display_view = None
         self._training_view = None
-        self._data_quality_view = None
 
         # Call superclass post_init
         super().__post_init__()
@@ -123,7 +127,8 @@ class FeatureSetCore(Artifact):
         """Return the size of the internal DataSource in MegaBytes"""
         return self.data_source.size()
 
-    def column_names(self) -> list[str]:
+    @property
+    def columns(self) -> list[str]:
         """Return the column names of the Feature Set"""
         return list(self.column_details().keys())
 
@@ -152,30 +157,29 @@ class FeatureSetCore(Artifact):
             ds_details[col] = fs_details.get(col, dtype)
         return ds_details
 
-    def get_display_view(self):
-        """Get the Display View for this Data Source"""
-        if self._display_view is None:
-            self._create_view("display")
-        return self._display_view
+    def views(self) -> list[str]:
+        """Return the views for this Data Source"""
+        from sageworks.core.views.view_utils import list_views
 
-    def get_training_view(self):
-        """Get the Training View for this Data Source"""
-        if self._training_view is None:
-            self._create_view("training")
-        return self._training_view
+        return list_views(self.data_source)
 
-    def get_data_quality_view(self):
-        """Get the Data Quality View for this Data Source"""
-        if self._data_quality_view is None:
-            self._create_view("data_quality")
-        return self._data_quality_view
+    def view(self, view_name: str) -> "View":
+        """Return a DataFrame for a specific view
+        Args:
+            view_name (str): The name of the view to return
+        Returns:
+            pd.DataFrame: A DataFrame for the specified view
+        """
+        from sageworks.core.views import View
+
+        return View(self, view_name)
 
     def get_display_columns(self) -> list[str]:
         """Get the columns from our display view
         Returns:
             list[str]: The columns from our display view
         """
-        return self.get_display_view().columns()
+        return self.view("display").columns
 
     def set_display_columns(self, display_columns: list[str], onboard: bool = True):
         """Set the display columns for this Data Source
@@ -185,28 +189,16 @@ class FeatureSetCore(Artifact):
             onboard (bool): Onboard the Data Source after setting the display columns (default: True)
         """
         self.log.important(f"Setting Display Columns...{display_columns}")
-        self.get_display_view().create_view(column_list=display_columns)
+        from sageworks.core.views import DisplayView
+
+        # Create a NEW display view
+        DisplayView(self).create(column_list=display_columns)
         if onboard:
             self.onboard()
 
-    def _create_view(self, view_type: str):
-        """Internal: Create the specified View for this FeatureSet
-
-        Args:
-            view_type (str): The type of view to create
-        """
-        from sageworks.core.views import DisplayView, TrainingView, DataQualityView
-
-        if view_type == "display":
-            self._display_view = DisplayView(self)
-        elif view_type == "training":
-            self._training_view = TrainingView(self)
-        elif view_type == "data_quality":
-            self._data_quality_view = DataQualityView(self)
-
     def num_columns(self) -> int:
         """Return the number of columns of the Feature Set"""
-        return len(self.column_names())
+        return len(self.columns)
 
     def num_rows(self) -> int:
         """Return the number of rows of the internal DataSource"""
@@ -263,7 +255,8 @@ class FeatureSetCore(Artifact):
         s3_output_path = self.feature_sets_s3_path + f"/{self.uuid}/datasets/all_{date_time}"
 
         # Make the query
-        query = f"SELECT * FROM {self.get_training_view().view_table_name}"
+        view_table_name = self.view("training").view_table_name
+        query = f"SELECT * FROM {view_table_name}"
         athena_query = FeatureGroup(name=self.uuid, sagemaker_session=self.sm_session).athena_query()
         athena_query.run(query, output_location=s3_output_path)
         athena_query.wait()
@@ -279,9 +272,9 @@ class FeatureSetCore(Artifact):
         Returns:
             pd.DataFrame: The training data for this FeatureSet
         """
-        from sageworks.core.views.view import View, ViewType
+        from sageworks.core.views.view import View
 
-        return View(self, ViewType.TRAINING).pull_dataframe()
+        return View(self, "training").pull_dataframe()
 
     def snapshot_query(self, table_name: str = None) -> str:
         """An Athena query to get the latest snapshot of features
@@ -293,7 +286,7 @@ class FeatureSetCore(Artifact):
             str: The Athena query to get the latest snapshot of features
         """
         # Remove FeatureGroup metadata columns that might have gotten added
-        columns = self.column_names()
+        columns = self.columns
         filter_columns = ["write_time", "api_invocation_time", "is_deleted"]
         columns = ", ".join(['"' + x + '"' for x in columns if x not in filter_columns])
 
@@ -375,7 +368,7 @@ class FeatureSetCore(Artifact):
         # Feature Sets can often have a lot of cruft so delete the entire bucket/prefix
         s3_delete_path = self.feature_sets_s3_path + f"/{self.uuid}/"
         self.log.info(f"Deleting All FeatureSet S3 Storage Objects {s3_delete_path}")
-        wr.s3.delete_objects(s3_delete_path, boto3_session=self.boto_session)
+        wr.s3.delete_objects(s3_delete_path, boto3_session=self.boto3_session)
 
         # Now delete any data in the Cache
         for key in self.data_storage.list_subkeys(f"feature_set:{self.uuid}:"):
@@ -385,6 +378,15 @@ class FeatureSetCore(Artifact):
         # Force a refresh of the AWS Metadata (to make sure references to deleted artifacts are gone)
         self.aws_broker.get_metadata(ServiceCategory.FEATURE_STORE, force_refresh=True)
 
+    def list_views(self) -> list[str]:
+        """List all the views associated with this FeatureSet"""
+        from sageworks.core.views.view_utils import list_view_tables
+
+        view_tables = list_view_tables(self.data_source)
+        data_table_name = self.data_source.get_table_name()
+        # Each view will have the format: {data_table_name}_{view_name}
+        return [view_table.replace(data_table_name + "_", "") for view_table in view_tables]
+
     def ensure_feature_group_deleted(self, feature_group):
         status = "Deleting"
         while status == "Deleting":
@@ -407,9 +409,10 @@ class FeatureSetCore(Artifact):
             id_column (str): The name of the id column.
             holdout_ids (list[str]): The list of holdout ids.
         """
+        from sageworks.core.views import TrainingView
 
-        # Create the training view
-        self.get_training_view().create_view(id_column, holdout_ids)
+        # Create a NEW training view
+        TrainingView(self.data_source).create(id_column=id_column, holdout_ids=holdout_ids)
 
     def get_training_view_table(self) -> Union[str, None]:
         """Get the name of the training view for this FeatureSet
@@ -418,10 +421,11 @@ class FeatureSetCore(Artifact):
             str: The name of the training view for this FeatureSet
         """
         # Get the training view table name
-        return self.get_training_view().view_table_name
+        return self.view("training").view_table_name
 
     def delete_views(self):
         """Delete any views associated with this FeatureSet"""
+        from sageworks.core.views.view_utils import delete_views_and_supplemental_data
 
         # Delete the views
         if self._display_view:
@@ -430,9 +434,9 @@ class FeatureSetCore(Artifact):
         if self._training_view:
             self._training_view.delete()
             self._training_view = None
-        if self._data_quality_view:
-            self._data_quality_view.delete()
-            self._data_quality_view = None
+
+        # Now delete any other views or supplemental data tables
+        delete_views_and_supplemental_data(self.data_source)
 
     def descriptive_stats(self, recompute: bool = False) -> dict:
         """Get the descriptive stats for the numeric columns of the underlying DataSource
@@ -599,8 +603,7 @@ if __name__ == "__main__":
     print(f"Rows: {num_rows} Columns: {num_columns}")
 
     # What are the column names?
-    columns = my_features.column_names()
-    print(columns)
+    print(my_features.columns)
 
     # Get the metadata and tags associated with this feature set
     print(f"SageWorks Meta: {my_features.sageworks_meta()}")
@@ -645,6 +648,10 @@ if __name__ == "__main__":
     my_holdout_ids = [name for name in df["name"] if int(name.split(" ")[1]) > 80]
     my_features.set_training_holdouts("name", my_holdout_ids)
 
+    # Get the training data
+    print("Getting the training data...")
+    training_data = my_features.get_training_data()
+
     # Now delete the AWS artifacts associated with this Feature Set
     # print('Deleting SageWorks Feature Set...')
     # my_features.delete()
