@@ -17,7 +17,7 @@ from sagemaker.model import Model as SagemakerModel
 # SageWorks Imports
 from sageworks.core.artifacts.artifact import Artifact
 from sageworks.aws_service_broker.aws_service_broker import ServiceCategory
-from sageworks.utils.aws_utils import newest_files, pull_s3_data
+from sageworks.utils.aws_utils import newest_path, pull_s3_data
 
 
 # Enumerated Model Types
@@ -94,16 +94,24 @@ class ModelCore(Artifact):
         # Call SuperClass Initialization
         super().__init__(model_uuid)
 
+        # Initialize our class attributes
+        self.latest_model = None
+        self.model_type = ModelType.UNKNOWN
+        self.model_training_path = None
+        self.endpoint_inference_path = None
+
         # Grab an AWS Metadata Broker object and pull information for Models
         self.model_name = model_uuid
         aws_meta = self.aws_broker.get_metadata(ServiceCategory.MODELS, force_refresh=force_refresh)
         self.model_meta = aws_meta.get(self.model_name)
         if self.model_meta is None:
             self.log.important(f"Could not find model {self.model_name} within current visibility scope")
-            self.latest_model = None
-            self.model_type = ModelType.UNKNOWN
             return
         else:
+            # Is this a model package group without any models?
+            if len(self.model_meta) == 0:
+                self.log.warning(f"Model Group {self.model_name} has no Model Packages!")
+                return
             try:
                 self.latest_model = self.model_meta[0]
                 self.description = self.latest_model.get("ModelPackageDescription", "-")
@@ -114,8 +122,6 @@ class ModelCore(Artifact):
                     self.model_type = self._get_model_type()
             except (IndexError, KeyError):
                 self.log.critical(f"Model {self.model_name} appears to be malformed. Delete and recreate it!")
-                self.latest_model = None
-                self.model_type = ModelType.UNKNOWN
                 return
 
         # Set the Model Training S3 Path
@@ -163,6 +169,12 @@ class ModelCore(Artifact):
             health_issues.append("metrics_needed")
         else:
             self.remove_health_tag("metrics_needed")
+
+        # Endpoint
+        if not self.endpoints():
+            health_issues.append("no_endpoint")
+        else:
+            self.remove_health_tag("no_endpoint")
         return health_issues
 
     def latest_model_object(self) -> SagemakerModel:
@@ -181,15 +193,46 @@ class ModelCore(Artifact):
         Returns:
             list[str]: List of inference run UUIDs
         """
-        if self.endpoint_inference_path is None:
-            return ["model_training"]  # Just the training run
-        directories = wr.s3.list_directories(path=self.endpoint_inference_path + "/")
-        inference_runs = [urlparse(directory).path.split("/")[-2] for directory in directories]
 
-        # We're going to add the training to the front of the list
-        inference_runs.insert(0, "model_training")
+        # Check if we have a model (if not return empty list)
+        if self.latest_model is None:
+            return []
+
+        # Check if we have model training metrics in our metadata
+        have_model_training = True if self.sageworks_meta().get("sageworks_training_metrics") else False
+
+        # Now grab the list of directories from our inference path
+        inference_runs = []
+        if self.endpoint_inference_path:
+            directories = wr.s3.list_directories(path=self.endpoint_inference_path + "/")
+            inference_runs = [urlparse(directory).path.split("/")[-2] for directory in directories]
+
+        # We're going to add the model training to the end of the list
+        if have_model_training:
+            inference_runs.append("model_training")
         return inference_runs
 
+    def delete_inference_run(self, inference_run_uuid: str):
+        """Delete the inference run for this model
+
+        Args:
+            inference_run_uuid (str): UUID of the inference run
+        """
+        if inference_run_uuid == "model_training":
+            self.log.warning("Cannot delete model training data!")
+            return
+
+        if self.endpoint_inference_path:
+            full_path = f"{self.endpoint_inference_path}/{inference_run_uuid}"
+            # Check if there are any objects at the path
+            if wr.s3.list_objects(full_path):
+                wr.s3.delete_objects(path=full_path)
+                self.log.important(f"Deleted inference run {inference_run_uuid} for {self.model_name}")
+            else:
+                self.log.warning(f"Inference run {inference_run_uuid} not found for {self.model_name}!")
+        else:
+            self.log.warning(f"No inference data found for {self.model_name}!")
+
     def get_inference_metrics(self, capture_uuid: str = "latest") -> Union[pd.DataFrame, None]:
         """Retrieve the inference performance metrics for this model
 
@@ -203,7 +246,7 @@ class ModelCore(Artifact):
         """
         # Try to get the auto_capture 'training_holdout' or the training
         if capture_uuid == "latest":
-            metrics_df = self.get_inference_metrics("training_holdout")
+            metrics_df = self.get_inference_metrics("auto_inference")
             return metrics_df if metrics_df is not None else self.get_inference_metrics("model_training")
 
         # Grab the metrics captured during model training (could return None)
@@ -277,12 +320,16 @@ class ModelCore(Artifact):
         """AWS ARN (Amazon Resource Name) for the Model Package Group"""
         return self.group_arn()
 
-    def group_arn(self) -> str:
+    def group_arn(self) -> Union[str, None]:
         """AWS ARN (Amazon Resource Name) for the Model Package Group"""
+        if self.latest_model is None:
+            return None
         return self.latest_model["ModelPackageGroupArn"]
 
-    def model_package_arn(self) -> str:
+    def model_package_arn(self) -> Union[str, None]:
         """AWS ARN (Amazon Resource Name) for the Model Package (within the Group)"""
+        if self.latest_model is None:
+            return None
         return self.latest_model["ModelPackageArn"]
 
     def container_info(self) -> dict:
@@ -299,10 +346,14 @@ class ModelCore(Artifact):
 
     def created(self) -> datetime:
         """Return the datetime when this artifact was created"""
+        if self.latest_model is None:
+            return "-"
         return self.latest_model["CreationTime"]
 
     def modified(self) -> datetime:
         """Return the datetime when this artifact was last modified"""
+        if self.latest_model is None:
+            return "-"
         return self.latest_model["CreationTime"]
 
     def register_endpoint(self, endpoint_name: str):
@@ -316,10 +367,32 @@ class ModelCore(Artifact):
         registered_endpoints.add(endpoint_name)
         self.upsert_sageworks_meta({"sageworks_registered_endpoints": list(registered_endpoints)})
 
+        # Remove any health tags
+        self.remove_health_tag("no_endpoint")
+
         # A new endpoint means we need to refresh our inference path
         time.sleep(2)  # Give the AWS Metadata a chance to update
         self.endpoint_inference_path = self.get_endpoint_inference_path()
 
+    def remove_endpoint(self, endpoint_name: str):
+        """Remove this endpoint from the set of registered endpoints for the model
+
+        Args:
+            endpoint_name (str): Name of the endpoint
+        """
+        self.log.important(f"Removing Endpoint {endpoint_name} from Model {self.uuid}...")
+        registered_endpoints = set(self.sageworks_meta().get("sageworks_registered_endpoints", []))
+        registered_endpoints.discard(endpoint_name)
+        self.upsert_sageworks_meta({"sageworks_registered_endpoints": list(registered_endpoints)})
+
+        # If we have NO endpionts, then set a health tags
+        if not registered_endpoints:
+            self.add_health_tag("no_endpoint")
+            self.details(recompute=True)
+
+        # A new endpoint means we need to refresh our inference path
+        time.sleep(2)
+
     def endpoints(self) -> list[str]:
         """Get the list of registered endpoints for this Model
 
@@ -328,8 +401,12 @@ class ModelCore(Artifact):
         """
         return self.sageworks_meta().get("sageworks_registered_endpoints", [])
 
-    def get_endpoint_inference_path(self) -> str:
-        """Get the S3 Path for the Inference Data"""
+    def get_endpoint_inference_path(self) -> Union[str, None]:
+        """Get the S3 Path for the Inference Data
+
+        Returns:
+            str: S3 Path for the Inference Data (or None if not found)
+        """
 
         # Look for any Registered Endpoints
         registered_endpoints = self.sageworks_meta().get("sageworks_registered_endpoints")
@@ -338,7 +415,13 @@ class ModelCore(Artifact):
         if registered_endpoints:
             endpoint_inference_base = self.endpoints_s3_path + "/inference/"
             endpoint_inference_paths = [endpoint_inference_base + e for e in registered_endpoints]
-            return newest_files(endpoint_inference_paths, self.sm_session)
+            inference_path = newest_path(endpoint_inference_paths, self.sm_session)
+            if inference_path is None:
+                self.log.important(f"No inference data found for {self.model_name}!")
+                self.log.important(f"Returning default inference path for {registered_endpoints[0]}...")
+                return endpoint_inference_paths[0]
+            else:
+                return inference_path
         else:
             self.log.warning(f"No registered endpoints found for {self.model_name}!")
             return None
@@ -417,11 +500,18 @@ class ModelCore(Artifact):
         details["model_type"] = self.model_type.value
         details["model_package_group_arn"] = self.group_arn()
         details["model_package_arn"] = self.model_package_arn()
+
+        # Sanity check is we have models in the group
         aws_meta = self.aws_meta()
+        if aws_meta is None:
+            self.log.warning(f"Model Package Group {self.model_name} has no models!")
+            return details
+
+        # Grab the Model Details
         details["description"] = aws_meta.get("ModelPackageDescription", "-")
         details["version"] = aws_meta["ModelPackageVersion"]
         details["status"] = aws_meta["ModelPackageStatus"]
-        details["approval_status"] = aws_meta["ModelApprovalStatus"]
+        details["approval_status"] = aws_meta.get("ModelApprovalStatus", "unknown")
         details["image"] = self.container_image().split("/")[-1]  # Shorten the image uri
 
         # Grab the inference and container info
@@ -619,7 +709,7 @@ class ModelCore(Artifact):
         try:
             s3_delete_path = f"{self.model_training_path}/"
             self.log.info(f"Deleting Training S3 Objects {s3_delete_path}")
-            wr.s3.delete_objects(s3_delete_path, boto3_session=self.boto_session)
+            wr.s3.delete_objects(s3_delete_path, boto3_session=self.boto3_session)
         except Exception:
             self.log.warning(f"Could not find/delete training artifacts for {self.model_name}!")
 
@@ -690,12 +780,12 @@ class ModelCore(Artifact):
                 {"sageworks_training_metrics": metrics_df.to_dict(), "sageworks_training_cm": cm_df.to_dict()}
             )
 
-    def _load_inference_metrics(self, capture_uuid: str = "training_holdout"):
+    def _load_inference_metrics(self, capture_uuid: str = "auto_inference"):
         """Internal: Retrieve the inference model metrics for this model
                      and load the data into the SageWorks Metadata
 
         Args:
-            capture_uuid (str, optional): A specific capture_uuid (default: "training_holdout")
+            capture_uuid (str, optional): A specific capture_uuid (default: "auto_inference")
         Notes:
             This may or may not exist based on whether an Endpoint ran Inference
         """
@@ -706,12 +796,12 @@ class ModelCore(Artifact):
         metrics_storage = None if inference_metrics is None else inference_metrics.to_dict("records")
         self.upsert_sageworks_meta({"sageworks_inference_metrics": metrics_storage})
 
-    def _load_inference_cm(self, capture_uuid: str = "training_holdout"):
+    def _load_inference_cm(self, capture_uuid: str = "auto_inference"):
         """Internal: Pull the inference Confusion Matrix for this model
                      and load the data into the SageWorks Metadata
 
         Args:
-            capture_uuid (str, optional): A specific capture_uuid (default: "training_holdout")
+            capture_uuid (str, optional): A specific capture_uuid (default: "auto_inference")
 
         Returns:
             pd.DataFrame: DataFrame of the inference Confusion Matrix (might be None)
@@ -726,11 +816,11 @@ class ModelCore(Artifact):
         cm_storage = None if inference_cm is None else inference_cm.to_dict("records")
         self.upsert_sageworks_meta({"sageworks_inference_cm": cm_storage})
 
-    def get_inference_metadata(self, capture_uuid: str = "training_holdout") -> Union[pd.DataFrame, None]:
+    def get_inference_metadata(self, capture_uuid: str = "auto_inference") -> Union[pd.DataFrame, None]:
         """Retrieve the inference metadata for this model
 
         Args:
-            capture_uuid (str, optional): A specific capture_uuid (default: "training_holdout")
+            capture_uuid (str, optional): A specific capture_uuid (default: "auto_inference")
 
         Returns:
             dict: Dictionary of the inference metadata (might be None)
@@ -764,7 +854,7 @@ class ModelCore(Artifact):
             self.log.info(f"Could not find model inference meta at {s3_path}...")
             return None
 
-    def get_inference_predictions(self, capture_uuid: str = "training_holdout") -> Union[pd.DataFrame, None]:
+    def get_inference_predictions(self, capture_uuid: str = "auto_inference") -> Union[pd.DataFrame, None]:
         """Retrieve the captured prediction results for this model
 
         Args:
@@ -789,6 +879,10 @@ class ModelCore(Artifact):
         Returns:
             pd.DataFrame: DataFrame of the Captured Validation Predictions (might be None)
         """
+        # Sanity check the training path (which may or may not exist)
+        if self.model_training_path is None:
+            self.log.warning(f"No Validation Predictions for {self.model_name}...")
+            return None
         self.log.important(f"Grabbing Validation Predictions for {self.model_name}...")
         s3_path = f"{self.model_training_path}/validation_predictions.csv"
         df = pull_s3_data(s3_path)
@@ -837,7 +931,7 @@ class ModelCore(Artifact):
 
         return metrics_df, cm_df
 
-    def shapley_values(self, capture_uuid: str = "training_holdout") -> Union[list[pd.DataFrame], pd.DataFrame, None]:
+    def shapley_values(self, capture_uuid: str = "auto_inference") -> Union[list[pd.DataFrame], pd.DataFrame, None]:
         """Retrieve the Shapely values for this model
 
         Args:
