@@ -226,7 +226,7 @@ class FeaturesToModel(Transform):
             # - Don't include any columns that are of type string or timestamp
             # - The rest of the columns are assumed to be features
             self.log.warning("Guessing at the feature list, HIGHLY SUGGESTED to specify an explicit feature list!")
-            all_columns = feature_set.column_names()
+            all_columns = feature_set.columns
             filter_list = [
                 "id",
                 "__index_level_0__",
@@ -323,7 +323,7 @@ class FeaturesToModel(Transform):
         self.log.info(f"Deleting training data {s3_training_path}...")
         wr.s3.delete_objects(
             [s3_training_path, s3_training_path.replace(".csv", ".csv.metadata")],
-            boto3_session=self.boto_session,
+            boto3_session=self.boto3_session,
         )
 
         # Create Model and officially Register
