@@ -11,8 +11,10 @@ import readline  # noqa
 
 try:
     import matplotlib.pyplot as plt  # noqa
+
+    HAVE_MATPLOTLIB = True
 except ImportError:
-    pass
+    HAVE_MATPLOTLIB = False
 
 
 # SageWorks Imports
@@ -21,7 +23,7 @@ from sageworks.utils.sageworks_logging import IMPORTANT_LEVEL_NUM, TRACE_LEVEL_N
 from sageworks.utils.config_manager import ConfigManager
 from sageworks.api.meta import Meta
 
-logging.getLogger("sageworks").setLevel(logging.INFO)
+logging.getLogger("sageworks").setLevel(IMPORTANT_LEVEL_NUM)
 
 
 class CustomPromptStyle(Style):
@@ -88,6 +90,10 @@ class SageWorksShell:
         config.TerminalInteractiveShell.highlighting_style = CustomPromptStyle
         self.shell = InteractiveShellEmbed(config=config, banner1="", exit_msg="Goodbye from SageWorks!")
 
+        # Set matplotlib to interactive mode
+        if HAVE_MATPLOTLIB:
+            self.shell.run_line_magic("matplotlib", "auto")
+
         # Register our custom commands
         self.commands["help"] = self.help
         self.commands["docs"] = self.doc_browser
@@ -167,14 +173,12 @@ class SageWorksShell:
         Returns:
             bool: True if AWS Account is set up correctly, False otherwise
         """
-        cprint("yellow", "Checking AWS Account Connection...")
+        cprint("lightgreen", "Checking AWS Account Connection...")
         try:
             try:
                 aws_clamp = importlib.import_module("sageworks.aws_service_broker.aws_account_clamp").AWSAccountClamp()
                 cprint("lightgreen", "AWS Account Clamp Created...")
                 aws_clamp.check_aws_identity()
-                cprint("lightgreen", "AWS Identity Check...")
-                aws_clamp.boto_session()
                 cprint("lightgreen", "AWS Account Check AOK!")
             except RuntimeError:
                 cprint("red", "AWS Account Check Failed: Check AWS_PROFILE and/or Renew SSO Token...")
@@ -214,18 +218,18 @@ class SageWorksShell:
         self.commands["ModelType"] = importlib.import_module("sageworks.api.model").ModelType
         self.commands["Endpoint"] = importlib.import_module("sageworks.api.endpoint").Endpoint
         self.commands["Monitor"] = importlib.import_module("sageworks.api.monitor").Monitor
+        self.commands["ParameterStore"] = importlib.import_module("sageworks.api.parameter_store").ParameterStore
         self.commands["PandasToFeatures"] = importlib.import_module(
             "sageworks.core.transforms.pandas_transforms"
         ).PandasToFeatures
         self.commands["Meta"] = importlib.import_module("sageworks.api.meta").Meta
         self.commands["View"] = importlib.import_module("sageworks.core.views.view").View
-        self.commands["ViewType"] = importlib.import_module("sageworks.core.views.view").ViewType
         self.commands["DisplayView"] = importlib.import_module("sageworks.core.views.display_view").DisplayView
-        self.commands["IdentityView"] = importlib.import_module("sageworks.core.views.identity_view").IdentityView
         self.commands["TrainingView"] = importlib.import_module("sageworks.core.views.training_view").TrainingView
-        self.commands["DataQualityView"] = importlib.import_module(
-            "sageworks.core.views.data_quality_view"
-        ).DataQualityView
+        self.commands["ComputationView"] = importlib.import_module(
+            "sageworks.core.views.computation_view"
+        ).ComputationView
+        self.commands["MDQView"] = importlib.import_module("sageworks.core.views.mdq_view").MDQView
 
         # We're going to include these classes/imports later
         # self.commands["Pipeline"] = importlib.import_module("sageworks.api.pipeline").Pipeline
