@@ -79,6 +79,11 @@ def list_tags_with_throttle(arn: str, sm_session) -> dict:
     sleep_times = [0.25, 0.5, 1, 2, 4, 8]
     max_attempts = len(sleep_times)
 
+    # Sanity check the ARN
+    if arn is None:
+        log.error("Called list_tags_with_throttle(arn==None)!")
+        return {}
+
     # Loop with exponential backoff
     for attempt in range(max_attempts):
         try:
@@ -313,8 +318,8 @@ def extract_data_source_basename(source: str) -> str:
         return source
 
 
-def newest_files(s3_locations: list[str], sm_session: SageSession) -> Union[str, None]:
-    """Determine which full S3 bucket and prefix combination has the newest files.
+def newest_path(s3_locations: list[str], sm_session: SageSession) -> Union[str, None]:
+    """Determine which S3 bucket and prefix combination has the newest files.
 
     Args:
         s3_locations (list[str]): A list of full S3 bucket and prefix combinations.
@@ -443,7 +448,7 @@ if __name__ == "__main__":
 
     # Grab out SageMaker Session from the AWS Account Clamp
     sm_session = AWSAccountClamp().sagemaker_session()
-    boto3_session = AWSAccountClamp().boto_session()
+    boto3_session = AWSAccountClamp().boto3_session
 
     my_features = FeatureSetCore("test_features")
     my_meta = my_features.sageworks_meta()
@@ -462,7 +467,7 @@ if __name__ == "__main__":
 
     # Test the newest files in an S3 folder method
     s3_path = "s3://sandbox-sageworks-artifacts/endpoints/inference/abalone-regression-end"
-    most_recent = newest_files([s3_path], sm_session)
+    most_recent = newest_path([s3_path], sm_session)
 
     # Add a health tag
     my_features.add_health_tag("needs_onboard")
