@@ -20,8 +20,8 @@ class EndpointMetrics:
         - Invocation4XXErrors: The number of client error status codes returned.
         """
         self.aws_account_clamp = AWSAccountClamp()
-        self.boto_session = self.aws_account_clamp.boto_session()
-        self.cloudwatch = self.boto_session.client("cloudwatch")
+        self.boto3_session = self.aws_account_clamp.boto3_session
+        self.cloudwatch = self.boto3_session.client("cloudwatch")
         self.start_time = None
         self.end_time = None
         self.metrics = [
