@@ -4,14 +4,18 @@ import sys
 import base64
 import json
 import logging
+import requests
 from typing import Union
-import importlib.resources as resources
+import importlib.resources as resources  # noqa: F401 Python 3.9 compatibility
 from datetime import datetime
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import padding
 from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.backends import default_backend
 
+# Python 3.9 compatibility
+from sageworks.utils.resource_utils import get_resource_path
+
 
 class FatalLicenseError(Exception):
     """Exception raised for fatal errors in API License."""
@@ -27,18 +31,25 @@ class LicenseManager:
     log = logging.getLogger("sageworks")
 
     @classmethod
-    def load_api_license(cls, aws_account_id: Union[str, None], api_key: str) -> Union[dict, None]:
+    def load_api_license(
+        cls, aws_account_id: Union[str, None], api_key: str, license_api_key: str = None
+    ) -> Union[dict, None]:
         """Internal: Load the SageWorks API License, verify it, and return the licensed features
         Args:
             aws_account_id(str): The AWS Account ID to verify the license against (None for Open Source)
             api_key(str): The SageWorks API Key to verify (base64 encoded)
+            license_api_key(str): The SageWorks License API Key (default: None)
         Returns:
             dict/None: The SageWorks API License Information or None if the license is invalid
         """
 
+        # Store the API Key for later use
+        cls.api_key = api_key
+        cls.license_api_key = license_api_key
+
         # Decode the API Key
         try:
-            decoded_license_key = base64.b64decode(api_key)
+            decoded_license_key = base64.urlsafe_b64decode(api_key)
             _license_data, signature = cls.extract_data_and_signature(decoded_license_key)
         except Exception as e:
             cls.log.critical(f"Failed to decode API Key: {e}")
@@ -127,13 +138,22 @@ class LicenseManager:
         Returns:
             The public key as an object.
         """
-        with resources.path("sageworks.resources", "signature_verify_pub.pem") as public_key_path:
+        # Python 3.9 compatibility
+        with get_resource_path("sageworks.resources", "signature_verify_pub.pem") as public_key_path:
             with open(public_key_path, "rb") as key_file:
                 public_key_data = key_file.read()
 
         public_key = serialization.load_pem_public_key(public_key_data, backend=default_backend())
         return public_key
 
+    @classmethod
+    def contact_license_server(cls) -> requests.Response:
+        """Contact the SageWorks License Server to verify the license."""
+        server_url = "https://sageworks-keyserver.com/decode-key"
+        headers = {"Content-Type": "application/json", "x-api-key": cls.license_api_key}
+        data = {"api_key": cls.api_key}
+        return requests.post(server_url, headers=headers, json=data)
+
 
 if __name__ == "__main__":
     """Exercise the License Manager class"""
@@ -142,9 +162,16 @@ if __name__ == "__main__":
     # Grab the API Key from the SageWorks ConfigManager
     cm = ConfigManager()
     api_key = cm.get_config("SAGEWORKS_API_KEY")
+    license_api_key = cm.get_config("LICENSE_API_KEY")
     print(LicenseManager.get_license_id())
 
-    my_license_info = LicenseManager.load_api_license(aws_account_id=None, api_key=api_key)
+    my_license_info = LicenseManager.load_api_license(
+        aws_account_id=None, api_key=api_key, license_api_key=license_api_key
+    )
     print(my_license_info)
     LicenseManager.print_license_info()
     print(LicenseManager.get_license_id())
+
+    # Test the license server
+    response = LicenseManager.contact_license_server()
+    print(response.json())
