@@ -1,4 +1,5 @@
 """A Markdown Component for details/information about DataSources (and FeatureSets)"""
+
 from dash import dcc
 
 # SageWorks Imports
@@ -238,4 +239,4 @@ if __name__ == "__main__":
     component.children = markdown
 
     if __name__ == "__main__":
-        app.run_server(debug=True)
+        app.run(debug=True)
