@@ -18,9 +18,9 @@ class RegressionPlot(ComponentInterface):
         # Initialize an empty scatter plot figure
         return dcc.Graph(id=component_id, figure=self.display_text("Waiting for Data..."))
 
-    def update_contents(self, model: Model, inference_run: str = None) -> go.Figure:
+    def update_properties(self, model: Model, inference_run: str = None) -> go.Figure:
         # Get predictions for specific inference
-        df = model.predictions(inference_run)
+        df = model.get_inference_predictions(inference_run)
 
         if df is None:
             return self.display_text("No Data")
@@ -49,7 +49,7 @@ class RegressionPlot(ComponentInterface):
             color_continuous_scale=color_scale,
         )
 
-        # Just fine tuning the dots on the scatter plot
+        # Just fine-tuning the dots on the scatter plot
         fig.update_traces(
             marker=dict(size=14, line=dict(width=1, color="Black")),
             selector=dict(mode="markers"),
@@ -67,7 +67,7 @@ class RegressionPlot(ComponentInterface):
             y1=max_val,
         )
 
-        # Just some fine tuning of the plot
+        # Just some fine-tuning of the plot
         fig.update_layout(margin={"t": 10, "b": 10, "r": 10, "l": 10, "pad": 10}, height=400)
 
         return fig
@@ -80,11 +80,11 @@ if __name__ == "__main__":
     m = Model("abalone-regression")
     my_inference_run = "model_training"
 
-    # Instantiate the ConfusionMatrix class
+    # Instantiate the RegressionPlot class
     reg_plot = RegressionPlot()
 
     # Generate the figure
-    fig = reg_plot.update_contents(m, my_inference_run)
+    fig = reg_plot.update_properties(m, my_inference_run)
 
     # Apply dark theme
     fig.update_layout(template="plotly_dark")
